@@ -1,6 +1,29 @@
 <?php
+/*****************************************************************************
+ *
+ * GlobalMainCfg.php - Class for handling the main configuration of NagVis
+ *
+ * Copyright (c) 2004-2008 NagVis Project (Contact: lars@vertical-visions.de)
+ *
+ * License:
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *****************************************************************************/
+ 
 /**
- * This Class handles the NagVis configuration file
+ * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class GlobalMainCfg {
 	var $config;
@@ -15,7 +38,6 @@ class GlobalMainCfg {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function GlobalMainCfg($configFile) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::GlobalMainCfg('.$configFile.')');
 		$this->config = Array();
 		$this->runtimeConfig = Array();
 		
@@ -25,6 +47,10 @@ class GlobalMainCfg {
 					'editable' => 1,
 					'default' => 'english',
 					'match' => MATCH_STRING_NO_SPACE),
+				'dateformat' => Array('must' => 1,
+					'editable' => 1,
+					'default' => 'Y-m-d H:i:s',
+					'match' => MATCH_STRING),
 				'displayheader' => Array('must' => 1,
 						'editable' => 1,
 						'default' => '1',
@@ -62,10 +88,18 @@ class GlobalMainCfg {
 					'editable' => 1,
 					'default' => 'default',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hovermenu' => Array('must' => 0,
+					'editable' => 1,
+					'default' => '1',
+					'match' => MATCH_BOOLEAN),
 				'hovertemplate' => Array('must' => 0,
 					'editable' => 1,
 					'default' => 'default',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hovertimeout' => Array('must' => 0,
+					'editable' => 1,
+					'default' => '5',
+					'match' => MATCH_INTEGER),
 				'hoverdelay' => Array('must' => 0,
 					'editable' => 1,
 					'default' => '0',
@@ -77,7 +111,23 @@ class GlobalMainCfg {
 				'urltarget' => Array('must' => 0,
 					'editable' => 1,
 					'default' => '_self',
-					'match' => MATCH_STRING_NO_SPACE)),
+					'match' => MATCH_STRING_NO_SPACE),
+				'hoverchildsshow' => Array('must' => 0,
+					'editable' => 1,
+					'default' => '1',
+					'match' => MATCH_BOOLEAN),
+				'hoverchildssort' => Array('must' => 0,
+					'editable' => 1,
+					'default' => 's',
+					'match' => MATCH_STRING_NO_SPACE),
+				'hoverchildsorder' => Array('must' => 0,
+					'editable' => 1,
+					'default' => 'asc',
+					'match' => MATCH_ORDER),
+				'hoverchildslimit' => Array('must' => 0,
+					'editable' => 1,
+					'default' => '10',
+					'match' => MATCH_INTEGER)),
 			'wui' => Array(
 					'autoupdatefreq' => Array('must' => 0,
 						'editable' => 1,
@@ -105,6 +155,10 @@ class GlobalMainCfg {
 					'editable' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_PATH),
+				'images' => Array('must' => 0,
+					'editable' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_PATH),
 				'shape' => Array('must' => 0,
 					'editable' => 0,
 					'default' => '',
@@ -117,6 +171,10 @@ class GlobalMainCfg {
 					'editable' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_PATH),
+				'var' => Array('must' => 0,
+					'editable' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_PATH),
 				'mapcfg' => Array('must' => 0,
 					'editable' => 0,
 					'default' => '',
@@ -124,7 +182,7 @@ class GlobalMainCfg {
 				'hovertemplate' => Array('must' => 0,
 					'editable' => 0,
 					'default' => '',
-					'type' => 'string'),
+					'match' => MATCH_STRING_PATH),
 				'headertemplate' => Array('must' => 0,
 					'editable' => 0,
 					'default' => '',
@@ -136,7 +194,7 @@ class GlobalMainCfg {
 				'htmlcgi' => Array('must' => 1,
 					'editable' => 1,
 					'default' => '/nagios/cgi-bin',
-					'match' => MATCH_STRING_PATH),
+					'match' => MATCH_STRING_URL),
 				'htmlimages' => Array('must' => 0,
 					'editable' => 0,
 					'default' => '/nagios/nagvis/nagvis/images/',
@@ -168,6 +226,10 @@ class GlobalMainCfg {
 				'htmlmap' => Array('must' => 0,
 					'editable' => 0,
 					'default' => '/nagios/nagvis/nagvis/images/maps/',
+					'match' => MATCH_STRING_PATH),
+				'htmlvar' => Array('must' => 0,
+					'editable' => 0,
+					'default' => '/nagios/var/',
 					'match' => MATCH_STRING_PATH)),
 			'backend' => Array(
 				'backendtype' => Array('must' => 1,
@@ -181,7 +243,7 @@ class GlobalMainCfg {
 				'htmlcgi' => Array('must' => 0,
 					'editable' => 1,
 					'default' => '',
-					'match' => MATCH_STRING_PATH),
+					'match' => MATCH_STRING_URL),
 				'options' => Array(
 					'ndomy' => Array('dbhost' => Array('must' => 1,
 							'editable' => 1,
@@ -206,7 +268,7 @@ class GlobalMainCfg {
 						'dbprefix' => Array('must' => 0,
 							'editable' => 1,
 							'default' => 'nagios_',
-							'match' => MATCH_STRING_NO_SPACE),
+							'match' => MATCH_STRING_NO_SPACE_EMPTY),
 						'dbinstancename' => Array('must' => 0,
 							'editable' => 1,
 							'default' => 'default',
@@ -228,33 +290,52 @@ class GlobalMainCfg {
 							'editable' => 1,
 							'default' => '/usr/local/nagios/sbin/',
 							'match' => MATCH_STRING_PATH)))),
-			'rotation' => Array('rotationid' => Array('must' => 1,
-				'editable' => 1,
-				'default' => 'demo',
-				'match' =>MATCH_STRING_NO_SPACE),
-			'maps' => Array('must' => 1,
-				'editable' => 1,
-				'default' => 'demo,demo2',
-				'match' => MATCH_STRING_NO_SPACE),
-			'interval' => Array('must' => 0,
-				'editable' => 1,
-				'default' => '',
-				'match' => MATCH_INTEGER)),
-			'internal' => Array('version' => Array('must' => 1,
-				'editable' => 0,
-				'default' => CONST_VERSION,
-				'locked' => 1,
-				'match' => MATCH_STRING_NO_SPACE),
-			'title' => Array('must' => 1,
-				'editable' => 0,
-				'default' => 'NagVis ' . CONST_VERSION,
-				'locked' => 1,
-				'match' => MATCH_STRING)));
+			'rotation' => Array(
+				'rotationid' => Array('must' => 1,
+					'editable' => 1,
+					'default' => 'demo',
+					'match' =>MATCH_STRING_NO_SPACE),
+				'maps' => Array('must' => 1,
+					'editable' => 1,
+					'default' => 'demo,demo2',
+					'match' => MATCH_STRING_NO_SPACE),
+				'interval' => Array('must' => 0,
+					'editable' => 1,
+					'default' => '',
+					'match' => MATCH_INTEGER)),
+			'automap' => Array(
+				'showinlists' => Array('must' => 0,
+					'editable' => 1,
+					'default' => '1',
+					'match' => MATCH_BOOLEAN),
+				'defaultroot' => Array('must' => 0,
+					'editable' => 1,
+					'default' => 'localhost',
+					'match' => MATCH_STRING_NO_SPACE_EMPTY),
+				'graphvizpath' => Array('must' => 0,
+					'editable' => 0,
+					'default' => '/usr/local/bin/',
+					'match' => MATCH_STRING_PATH),
+				'defaultparams' => Array('must' => 0,
+					'editable' => 0,
+					'default' => '&maxLayers=2',
+					'match' => MATCH_STRING_URL)),
+			'internal' => Array(
+				'version' => Array('must' => 1,
+					'editable' => 0,
+					'default' => CONST_VERSION,
+					'locked' => 1,
+					'match' => MATCH_STRING_NO_SPACE),
+				'title' => Array('must' => 1,
+					'editable' => 0,
+					'default' => 'NagVis ' . CONST_VERSION,
+					'locked' => 1,
+					'match' => MATCH_STRING)));
 		
 		// Try to get the base path via $_SERVER['SCRIPT_FILENAME']
 		$this->validConfig['paths']['base']['default'] = $this->getBasePath();
 		$this->setPathsByBase($this->getValue('paths','base'),$this->getValue('paths','htmlbase'));
-			
+		
 		// Read Main Config file
 		$this->configFile = $configFile;
 		$this->readConfig(1);
@@ -265,8 +346,6 @@ class GlobalMainCfg {
 		// set default value
 		$this->validConfig['rotation']['interval']['default'] = $this->getValue('global','refreshtime');
 		$this->validConfig['backend']['htmlcgi']['default'] = $this->getValue('paths','htmlcgi');
-		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::GlobalMainCfg()');
 	}
 	
 	/**
@@ -279,10 +358,12 @@ class GlobalMainCfg {
 	function setPathsByBase($base,$htmlBase) {
 		$this->validConfig['paths']['cfg']['default'] = $base.'etc/';
 		$this->validConfig['paths']['icon']['default'] = $base.'nagvis/images/iconsets/';
+		$this->validConfig['paths']['images']['default'] = $base.'nagvis/images/';
 		$this->validConfig['paths']['shape']['default'] = $base.'nagvis/images/shapes/';
 		$this->validConfig['paths']['language']['default'] = $base.'nagvis/includes/languages/';
 		$this->validConfig['paths']['class']['default'] = $base.'nagvis/includes/classes/';
 		$this->validConfig['paths']['map']['default'] = $base.'nagvis/images/maps/';
+		$this->validConfig['paths']['var']['default'] = $base.'var/';
 		$this->validConfig['paths']['hovertemplate']['default'] = $base.'nagvis/templates/hover/';
 		$this->validConfig['paths']['headertemplate']['default'] = $base.'nagvis/templates/header/';
 		$this->validConfig['paths']['mapcfg']['default'] = $base.'etc/maps/';
@@ -294,6 +375,7 @@ class GlobalMainCfg {
 		$this->validConfig['paths']['htmlicon']['default'] = $htmlBase.'/nagvis/images/iconsets/';
 		$this->validConfig['paths']['htmlshape']['default'] = $htmlBase.'/nagvis/images/shapes/';
 		$this->validConfig['paths']['htmlmap']['default'] = $htmlBase.'/nagvis/images/maps/';
+		$this->validConfig['paths']['htmlvar']['default'] = $htmlBase.'/var/';
 	}
 	
 	/**
@@ -304,9 +386,7 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getBasePath() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::getBasePath()');
 		$return = preg_replace('/wui|nagvis$/i', '', realpath(dirname($_SERVER['SCRIPT_FILENAME'])));
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::getBasePath(): '.$return);
 		return $return ;
 	}
 	
@@ -318,39 +398,41 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function readConfig($printErr=1) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::readConfig('.$printErr.')');
 		$numComments = 0;
 		$sec = '';
 		
 		// Check for config file and read permissions
 		if($this->checkNagVisConfigExists($printErr) && $this->checkNagVisConfigReadable($printErr)) {
 			// read thx config file line by line in array $file
-			$file = @file($this->configFile);
+			$file = file($this->configFile);
+			
+			// Count the lines before the loop (only counts once)
+			$countLines = count($file);
 			
 			// loop trough array
-			for ($i = 0; $i < @count($file); $i++) {
+			for ($i = 0; $i < $countLines; $i++) {
 				// cut spaces from beginning and end
-				$line = @trim($file[$i]);
+				$line = trim($file[$i]);
 				
 				// don't read empty lines
 				if(isset($line) && $line != '') {
 					// get first char of actual line
-					$firstChar = @substr($line,0,1);
+					$firstChar = substr($line,0,1);
 					
 					// check what's in this line
 					if($firstChar == ';') {
 						// comment...
 						$key = 'comment_'.($numComments++);
-						$val = @trim($line);
+						$val = trim($line);
 						
 						if(isset($sec) && $sec != '') {
 							$this->config[$sec][$key] = $val;
 						} else {
 							$this->config[$key] = $val;
 						}
-					} elseif ((@substr($line, 0, 1) == '[') && (@substr($line, -1, 1)) == ']') {
+					} elseif ((substr($line, 0, 1) == '[') && (substr($line, -1, 1)) == ']') {
 						// section
-						$sec = @strtolower(@trim(@substr($line, 1, @strlen($line)-2)));
+						$sec = strtolower(trim(substr($line, 1, strlen($line)-2)));
 						
 						// write to array
 						if(preg_match('/^backend_/i', $sec)) {
@@ -366,16 +448,16 @@ class GlobalMainCfg {
 						// parameter...
 						
 						// seperate string in an array
-						$arr = @explode('=',$line);
+						$arr = explode('=',$line);
 						// read key from array and delete it
-						$key = @strtolower(@trim($arr[0]));
+						$key = strtolower(trim($arr[0]));
 						unset($arr[0]);
 						// build string from rest of array
-						$val = @trim(@implode('=', $arr));
+						$val = trim(implode('=', $arr));
 						
 						// remove " at beginign and at the end of the string
-						if ((@substr($val,0,1) == '"') && (@substr($val,-1,1)=='"')) {
-							$val = @substr($val,1,@strlen($val)-2);
+						if ((substr($val,0,1) == '"') && (substr($val,-1,1)=='"')) {
+							$val = substr($val,1,strlen($val)-2);
 						}
 						
 						// Special options (Arrays)
@@ -397,14 +479,11 @@ class GlobalMainCfg {
 			}
 			
 			if($this->checkMainConfigIsValid(1)) {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::readConfig(): TRUE');
 				return TRUE;
 			} else {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::readConfig(): FALSE');
 				return FALSE;
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::readConfig(): FALSE');
 			return FALSE;
 		}
 	}
@@ -417,12 +496,11 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkMainConfigIsValid($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::checkMainConfigIsValid('.$printErr.')');
 		
 		// check given objects and attributes
-		foreach($this->config AS $type => $vars) {
+		foreach($this->config AS $type => &$vars) {
 			if(!ereg('^comment_',$type)) {
-				if(array_key_exists($type,$this->validConfig) || ereg('^(backend|rotation)_', $type)) {
+				if(isset($this->validConfig[$type]) || ereg('^(backend|rotation)_', $type)) {
 					// loop validConfig for checking: => missing "must" atributes
 					if(ereg('^backend_', $type)) {
 						$arrValidConfig = array_merge($this->validConfig['backend'],$this->validConfig['backend']['options'][$this->getValue($type,'backendtype')]);
@@ -431,7 +509,7 @@ class GlobalMainCfg {
 					} else {
 						$arrValidConfig = $this->validConfig[$type];
 					}
-					foreach($arrValidConfig AS $key => $val) {
+					foreach($arrValidConfig AS $key => &$val) {
 						if((isset($val['must']) && $val['must'] == '1')) {
 							// value is "must"
 							if($this->getValue($type,$key) == '') {
@@ -453,13 +531,12 @@ class GlobalMainCfg {
 								$arrValidConfig = $this->validConfig[$type];
 							}
 							
-							if(!array_key_exists($key,$arrValidConfig)) {
+							if(!isset($arrValidConfig[$key])) {
 								// unknown attribute
 								if($printErr) {
 									$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 									$FRONTEND->messageToUser('ERROR','unknownValue','ATTRIBUTE~'.$key.',TYPE~'.$type);
 								}
-								if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigIsValid(): FALSE');
 								return FALSE;
 							} else {
 								if(isset($val) && is_array($val)) {
@@ -473,7 +550,6 @@ class GlobalMainCfg {
 										$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 										$FRONTEND->messageToUser('ERROR','wrongValueFormat','TYPE~'.$type.',ATTRIBUTE~'.$key);
 									}
-									if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigIsValid(): FALSE');
 									return FALSE;
 								}
 							}
@@ -485,12 +561,10 @@ class GlobalMainCfg {
 						$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 						$FRONTEND->messageToUser('ERROR','unknownSection','TYPE~'.$type);
 					}
-					if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkMainConfigIsValid(): FALSE');
 					return FALSE;
 				}
 			}
 		}
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkMainConfigIsValid(): TRUE');
 		return TRUE;
 	}
 	
@@ -501,14 +575,13 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function writeConfig() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::writeConfig()');
 		// Check for config file and read permissions
 		if($this->checkNagVisConfigReadable(1) && $this->checkNagVisConfigWriteable(1)) {
-			foreach($this->config as $key => $item) {
+			foreach($this->config as $key => &$item) {
 				if(is_array($item)) {
 					$content .= '['.$key.']'."\n";
-					foreach ($item as $key2 => $item2) {
-						if(@substr($key2,0,8) == 'comment_') {
+					foreach ($item as $key2 => &$item2) {
+						if(substr($key2,0,8) == 'comment_') {
 							$content .= $item2."\n";
 						} else {
 							if(is_numeric($item2) || is_bool($item2))
@@ -517,7 +590,7 @@ class GlobalMainCfg {
 							$content .= $key2.'="'.$item2.'"'."\n";
 						}
 					}
-				} elseif(@substr($key,0,8) == 'comment_') {
+				} elseif(substr($key,0,8) == 'comment_') {
 					$content .= $item."\n";
 				} else {
 					if(is_numeric($item) || is_bool($item))
@@ -530,22 +603,18 @@ class GlobalMainCfg {
 			if(!$handle = fopen($this->configFile, 'w+')) {
 				$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 				$FRONTEND->messageToUser('ERROR','mainCfgNotWriteable');
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::writeConfig(): FALSE');
 				return FALSE;
 			}
 			
 			if(!fwrite($handle, $content)) {
 				$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 				$FRONTEND->messageToUser('ERROR','19');
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::writeConfig(): FALSE');
 				return FALSE;
 			}
 			
 			fclose($handle);
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::writeConfig(): TRUE');
 			return TRUE;
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::writeConfig(): FALSE');
 			return FALSE;
 		}
 	}
@@ -558,21 +627,17 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkNagVisConfigExists($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::checkNagVisConfigExists('.$printErr.')');
 		if($this->configFile != '') {
 			if(file_exists($this->configFile)) {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigExists(): TRUE');
 				return TRUE;
 			} else {
 				if($printErr == 1) {
 					$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 					$FRONTEND->messageToUser('ERROR','mainCfgNotExists','MAINCFG~'.$this->configFile);
 				}
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigExists(): FALSE');
 				return FALSE;
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigExists(): FALSE');
 			return FALSE;
 		}
 	}
@@ -585,21 +650,17 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkNagVisConfigReadable($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::checkNagVisConfigReadable('.$printErr.')');
 		if($this->configFile != '') {
 			if(is_readable($this->configFile)) {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigReadable(): TRUE');
 				return TRUE;
 			} else {
 				if($printErr == 1) {
 					$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 					$FRONTEND->messageToUser('ERROR','mainCfgNotReadable','MAINCFG~'.$this->configFile);
 				}
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigReadable(): FALSE');
 				return FALSE;
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigReadable(): FALSE');
 			return FALSE;
 		}
 	}
@@ -612,16 +673,13 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkNagVisConfigWriteable($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::checkNagVisConfigWriteable('.$printErr.')');
 		if($this->checkNagVisConfigExists($printErr) && is_writeable($this->configFile)) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigWriteable(): TRUE');
 			return TRUE;
 		} else {
 			if($printErr == 1) {
 				$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 				$FRONTEND->messageToUser('ERROR','mainCfgNotWriteable','MAINCFG~'.$this->configFile);
 			}
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkNagVisConfigWriteable(): FALSE');
 			return FALSE;
 		}
 	}
@@ -634,16 +692,13 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkMapCfgFolderReadable($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::checkMapCfgFolderReadable('.$printErr.')');
-		if(file_exists($this->getValue('paths', 'mapcfg')) && @is_readable($this->getValue('paths', 'mapcfg'))) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkMapCfgFolderReadable(): FALSE');
+		if(file_exists($this->getValue('paths', 'mapcfg')) && is_readable($this->getValue('paths', 'mapcfg'))) {
 			return TRUE;
 		} else {
 			if($printErr == 1) {
 				$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 				$FRONTEND->messageToUser('ERROR','mapCfgDirNotReadable','MAPPATH~'.$this->getValue('paths', 'mapcfg'));
 			}
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkMapCfgFolderReadable(): FALSE');
 			return FALSE;
 		}
 	}
@@ -656,16 +711,13 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkMapCfgFolderWriteable($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::checkMapCfgFolderWriteable('.$printErr.')');
-		if(file_exists(substr($this->getValue('paths', 'mapcfg'),0,-1)) && @is_writable(substr($this->getValue('paths', 'mapcfg'),0,-1))) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkMapCfgFolderWriteable(): TRUE');
+		if(file_exists(substr($this->getValue('paths', 'mapcfg'),0,-1)) && is_writable(substr($this->getValue('paths', 'mapcfg'),0,-1))) {
 			return TRUE;
 		} else {
 			if($printErr == 1) {
 				$FRONTEND = new GlobalPage($this,Array('languageRoot'=>'global:global'));
 				$FRONTEND->messageToUser('ERROR','mapCfgDirNotWriteable','MAPPATH~'.$this->getValue('paths', 'mapcfg'));
 			}
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::checkMapCfgFolderWriteable(): FALSE');
 			return FALSE;
 		}
 	}
@@ -678,20 +730,17 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function findSecOfVar($var) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::findSecOfVar('.$var.')');
-		foreach($this->validConfig AS $key => $item) {
+		foreach($this->validConfig AS $key => &$item) {
 			if(is_array($item)) {
-				foreach ($item AS $key2 => $item2) {
-					if(@substr($key2,0,8) != 'comment_') {
+				foreach ($item AS $key2 => &$item2) {
+					if(substr($key2,0,8) != 'comment_') {
 						if($key2 == $var) {
-							if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::findSecOfVar(): '.$key);
 							return $key;
 						}
 					}
 				}
 			}
 		}
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::findSecOfVar(): FALSE');
 		return FALSE;
 	}
 	
@@ -705,7 +754,6 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function setValue($sec, $var, $val) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::setValue('.$sec.','.$var.','.$val.')');
 		if(isset($this->config[$sec][$var]) && $val == '') {
 			// Value is empty and there is an entry in the config array
 			unset($this->config[$sec][$var]);
@@ -715,7 +763,6 @@ class GlobalMainCfg {
 			// Value is set
 			$this->config[$sec][$var] = $val;
 		}
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::setValue(): TRUE');
 		return TRUE;
 	}
 	
@@ -729,61 +776,45 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getValue($sec, $var, $ignoreDefault=FALSE) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::getValue('.$sec.','.$var.','.$ignoreDefault.')');
 		// if nothing is set in the config file, use the default value
-		if(isset($this->config[$sec]) && is_array($this->config[$sec]) && array_key_exists($var,$this->config[$sec])) {
-			if (DEBUG&&DEBUGLEVEL&2) debug('  Value is set in the config file');
-			
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->config[$sec][$var]);
+		if(isset($this->config[$sec]) && is_array($this->config[$sec]) && isset($this->config[$sec][$var])) {
 			return $this->config[$sec][$var];
 		} elseif(!$ignoreDefault) {
-			if (DEBUG&&DEBUGLEVEL&2) debug('  Not set in config file, try to get default value');
-			if(preg_match('/^backend_/i', $sec)) {
-				if (DEBUG&&DEBUGLEVEL&2) debug('  Section: Backend');
-				
+			// Enfasten this method by first check for famous sections and only if 
+			// they don't match try to match the backend_ and rotation_ sections
+			if($sec == 'global' || $sec == 'defaults' || $sec == 'paths') {
+				return $this->validConfig[$sec][$var]['default'];
+			} elseif(strpos($sec, 'backend_') === 0) {
+				// If backendtype specified, return the default value of this backend
 				if(isset($this->config[$sec]['backendtype']) && $this->config[$sec]['backendtype'] != '') {
-					if (DEBUG&&DEBUGLEVEL&2) debug('  Backendtype is set in the backend, get the default value from backend default options');
-					
-					if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->validConfig['backend']['options'][$this->config[$sec]['backendtype']][$var]['default']);
-					return $this->validConfig['backend']['options'][$this->config[$sec]['backendtype']][$var]['default'];
+					if(isset($this->validConfig['backend']['options'][$this->config[$sec]['backendtype']][$var]['default']) && $this->validConfig['backend']['options'][$this->config[$sec]['backendtype']][$var]['default'] != '') {
+						return $this->validConfig['backend']['options'][$this->config[$sec]['backendtype']][$var]['default'];
+					} else {
+						return $this->validConfig['backend'][$var]['default'];
+					}
 				} else {
-					if (DEBUG&&DEBUGLEVEL&2) debug('  Backendtype is not set in the backend, get the options of the default backend');
-					
+					// When exists, return the default value of the default backend
 					if(isset($this->validConfig['backend']['options'][$this->validConfig['backend']['backendtype']['default']][$var]['default']) && $this->validConfig['backend']['options'][$this->validConfig['backend']['backendtype']['default']][$var]['default'] != '') {
-						if (DEBUG&&DEBUGLEVEL&2) debug('  Got default value from the default backend');
-						
-						if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->validConfig['backend']['options'][$this->validConfig['backend']['backendtype']['default']][$var]['default']);
 						return $this->validConfig['backend']['options'][$this->validConfig['backend']['backendtype']['default']][$var]['default'];
 					} else {
-						if (DEBUG&&DEBUGLEVEL&2) debug('  The default value is empty or not set in the default backend');
+						// When exists, return the default value of backend-global options
 						if(isset($this->validConfig['backend'][$var]['default']) && $this->validConfig['backend'][$var]['default'] != '') {
-							if (DEBUG&&DEBUGLEVEL&2) debug('  Found the value in "global" backend section');
-							
-							if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->validConfig['backend'][$var]['default']);
 							return $this->validConfig['backend'][$var]['default'];
 						} else {
-							if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->validConfig['backend']['backendtype']['default']);
 							return $this->validConfig['backend']['backendtype']['default'];
 						}
 					}
 				}
-			} elseif(preg_match('/^rotation_/i', $sec)) {
-				if (DEBUG&&DEBUGLEVEL&2) debug('  Section: Rotation');
-				
+			} elseif(strpos($sec, 'rotation_') === 0) {
 				if(isset($this->config[$sec]) && is_array($this->config[$sec])) {
-					if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->validConfig['rotation'][$var]['default']);
-						return $this->validConfig['rotation'][$var]['default'];
+					return $this->validConfig['rotation'][$var]['default'];
 				} else {
 					return FALSE;
 				}
 			} else {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): '.$this->validConfig[$sec][$var]['default']);
 				return $this->validConfig[$sec][$var]['default'];
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&2) debug('  Not set in config file, not allowed to get default value');
-			
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getValue(): FALSE');
 			return FALSE;
 		}
 	}
@@ -797,9 +828,7 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function setRuntimeValue($var, $val) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::setRuntimeValue('.$var.','.$val.')');
 		$this->runtimeConfig[$var] = $val;
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::setRuntimeValue(): TRUE');
 		return TRUE;
 	}
 	
@@ -811,14 +840,11 @@ class GlobalMainCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getRuntimeValue($var) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMainCfg::getRuntimeValue('.$var.')');
 		if(isset($this->runtimeConfig[$var])) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getRuntimeValue(): '.$this->runtimeConfig[$var]);
 			return $this->runtimeConfig[$var];
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMainCfg::getRuntimeValue(): ""');
 			return '';
 		}
 	}
 }
-?>
\ No newline at end of file
+?>
