@@ -1,8 +1,29 @@
 <?php
-/**
- * This Class handles the NagVis configuration file
+/*****************************************************************************
  *
- * @author 	Lars Michelsen <lars@vertical-visions.de>
+ * GlobalMapCfg.php - Class for handling the map configuration files of NagVis
+ *
+ * Copyright (c) 2004-2008 NagVis Project (Contact: lars@vertical-visions.de)
+ *
+ * License:
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *****************************************************************************/
+ 
+/**
+ * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class GlobalMapCfg {
 	var $MAINCFG;
@@ -22,7 +43,6 @@ class GlobalMapCfg {
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function GlobalMapCfg(&$MAINCFG,$name='') {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::GlobalMapCfg($MAINCFG,'.$name.')');
 		$this->MAINCFG = &$MAINCFG;
 		$this->name	= $name;
 		
@@ -30,9 +50,9 @@ class GlobalMapCfg {
 			'global' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'allowed_for_config' => Array('must' => 1,
-					'match' => MATCH_STRING_NO_SPACE),
+					'match' => MATCH_STRING),
 				'allowed_user' => Array('must' => 1,
-					'match' => MATCH_STRING_NO_SPACE),
+					'match' => MATCH_STRING),
 				'map_image' => Array('must' => 1,
 					'match' => MATCH_PNGFILE),
 				'alias' => Array('must' => 0,
@@ -62,6 +82,12 @@ class GlobalMapCfg {
 				'hover_template' => Array('must' => 0,
 					'default' => $this->MAINCFG->getValue('defaults', 'hovertemplate'),
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_timeout' => Array('must' => 0,
+					'default' => $this->MAINCFG->getValue('defaults', 'hovertimeout'),
+					'match' => MATCH_INTEGER),
+				'hover_menu' => Array('must' => 0,
+					'default' => $this->MAINCFG->getValue('defaults', 'hovermenu'),
+					'match' => MATCH_BOOLEAN),
 				'hover_delay' => Array('must' => 0,
 					'default' => $this->MAINCFG->getValue('defaults', 'hoverdelay'),
 					'match' => MATCH_INTEGER),
@@ -85,7 +111,25 @@ class GlobalMapCfg {
 					'match' => MATCH_INTEGER),
 				'label_background' => Array('must' => 0,
 					'default' => 'transparent',
-					'match' => MATCH_COLOR)),
+					'match' => MATCH_COLOR),
+				'label_border' => Array('must' => 0,
+					'default' => '#000000',
+					'match' => MATCH_COLOR),
+				'in_maintenance' => Array('must' => 0,
+					'default' => '0',
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_show' => Array('must' => 0,
+					'default' => $this->MAINCFG->getValue('defaults', 'hoverchildsshow'),
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_sort' => Array('must' => 0,
+					'default' => $this->MAINCFG->getValue('defaults', 'hoverchildssort'),
+					'match' => MATCH_STRING_NO_SPACE),
+				'hover_childs_order' => Array('must' => 0,
+					'default' => $this->MAINCFG->getValue('defaults', 'hoverchildsorder'),
+					'match' => MATCH_ORDER),
+				'hover_childs_limit' => Array('must' => 0,
+					'default' => $this->MAINCFG->getValue('defaults', 'hoverchildslimit'),
+					'match' => MATCH_INTEGER)),
 			'host' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'use' => Array('must' => 0,
@@ -94,7 +138,7 @@ class GlobalMapCfg {
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
 				'host_name' => Array('must' => 1,
-					'match' => MATCH_STRING_NO_SPACE),
+					'match' => MATCH_STRING),
 				'x' => Array('must' => 1,
 					'match' => MATCH_FLOAT),
 				'y' => Array('must' => 1,
@@ -111,9 +155,14 @@ class GlobalMapCfg {
 				'iconset' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_menu' => Array('must' => 0,
+					'match' => MATCH_BOOLEAN),
 				'hover_template' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_timeout' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER),
 				'hover_delay' => Array('must' => 0,
 					'match' => MATCH_INTEGER),
 				'hover_url' => Array('must' => 0,
@@ -141,7 +190,22 @@ class GlobalMapCfg {
 					'match' => MATCH_INTEGER),
 				'label_background' => Array('must' => 0,
 					'default' => '',
-					'match' => MATCH_COLOR)),
+					'match' => MATCH_COLOR),
+				'label_border' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_COLOR),
+				'hover_childs_show' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_sort' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_NO_SPACE),
+				'hover_childs_order' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_ORDER),
+				'hover_childs_limit' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER)),
 			'hostgroup' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'use' => Array('must' => 0,
@@ -167,9 +231,14 @@ class GlobalMapCfg {
 				'iconset' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_menu' => Array('must' => 0,
+					'match' => MATCH_BOOLEAN),
 				'hover_template' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_timeout' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER),
 				'hover_delay' => Array('must' => 0,
 					'match' => MATCH_INTEGER),
 				'hover_url' => Array('must' => 0,
@@ -197,7 +266,22 @@ class GlobalMapCfg {
 					'match' => MATCH_INTEGER),
 				'label_background' => Array('must' => 0,
 					'default' => '',
-					'match' => MATCH_COLOR)),
+					'match' => MATCH_COLOR),
+				'label_border' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_COLOR),
+				'hover_childs_show' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_sort' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_NO_SPACE),
+				'hover_childs_order' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_ORDER),
+				'hover_childs_limit' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER)),
 			'service' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'use' => Array('must' => 0,
@@ -206,8 +290,9 @@ class GlobalMapCfg {
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
 				'host_name' => Array('must' => 1,
-					'match' => MATCH_STRING_NO_SPACE),
-				'service_description' => Array('must' => 1),
+					'match' => MATCH_STRING),
+				'service_description' => Array('must' => 1,
+					'match' => MATCH_STRING),
 				'x' => Array('must' => 1,
 					'match' => MATCH_FLOAT),
 				'y' => Array('must' => 1,
@@ -221,9 +306,14 @@ class GlobalMapCfg {
 				'iconset' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_menu' => Array('must' => 0,
+					'match' => MATCH_BOOLEAN),
 				'hover_template' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_timeout' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER),
 				'hover_delay' => Array('must' => 0,
 					'match' => MATCH_INTEGER),
 				'hover_url' => Array('must' => 0,
@@ -251,7 +341,22 @@ class GlobalMapCfg {
 					'match' => MATCH_INTEGER),
 				'label_background' => Array('must' => 0,
 					'default' => '',
-					'match' => MATCH_COLOR)),
+					'match' => MATCH_COLOR),
+				'label_border' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_COLOR),
+				'hover_childs_show' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_sort' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_NO_SPACE),
+				'hover_childs_order' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_ORDER),
+				'hover_childs_limit' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER)),
 			'servicegroup' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'use' => Array('must' => 0,
@@ -260,7 +365,7 @@ class GlobalMapCfg {
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
 				'servicegroup_name' => Array('must' => 1,
-					'match' => MATCH_STRING_NO_SPACE),
+					'match' => MATCH_STRING),
 				'x' => Array('must' => 1,
 					'match' => MATCH_FLOAT),
 				'y' => Array('must' => 1,
@@ -274,9 +379,14 @@ class GlobalMapCfg {
 				'iconset' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_menu' => Array('must' => 0,
+					'match' => MATCH_BOOLEAN),
 				'hover_template' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_timeout' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER),
 				'hover_delay' => Array('must' => 0,
 					'match' => MATCH_INTEGER),
 				'hover_url' => Array('must' => 0,
@@ -304,7 +414,22 @@ class GlobalMapCfg {
 					'match' => MATCH_INTEGER),
 				'label_background' => Array('must' => 0,
 					'default' => '',
-					'match' => MATCH_COLOR)),
+					'match' => MATCH_COLOR),
+				'label_border' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_COLOR),
+				'hover_childs_show' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_sort' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_NO_SPACE),
+				'hover_childs_order' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_ORDER),
+				'hover_childs_limit' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER)),
 			'map' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'use' => Array('must' => 0,
@@ -328,9 +453,14 @@ class GlobalMapCfg {
 					'match' => MATCH_STRING_URL),
 				'url_target' => Array('must' => 0,
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_menu' => Array('must' => 0,
+					'match' => MATCH_BOOLEAN),
 				'hover_template' => Array('must' => 0,
 					'default' => '',
 					'match' => MATCH_STRING_NO_SPACE),
+				'hover_timeout' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER),
 				'hover_delay' => Array('must' => 0,
 					'match' => MATCH_INTEGER),
 				'hover_url' => Array('must' => 0,
@@ -352,7 +482,22 @@ class GlobalMapCfg {
 					'match' => MATCH_INTEGER),
 				'label_background' => Array('must' => 0,
 					'default' => '',
-					'match' => MATCH_COLOR)),
+					'match' => MATCH_COLOR),
+				'label_border' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_COLOR),
+				'hover_childs_show' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_BOOLEAN),
+				'hover_childs_sort' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_STRING_NO_SPACE),
+				'hover_childs_order' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_ORDER),
+				'hover_childs_limit' => Array('must' => 0,
+					'default' => '',
+					'match' => MATCH_INTEGER)),
 			'textbox' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'use' => Array('must' => 0,
@@ -367,9 +512,12 @@ class GlobalMapCfg {
 					'default' => 1,
 					'match' => MATCH_INTEGER),
 				'w' => Array('must' => 1,
-					'match' => MATCH_INTEGER),
+					'match' => MATCH_TEXTBOX_WIDTH),
 				'background_color' => Array('must' => 0,
 					'default' => '#C0C0C0',
+					'match' => MATCH_COLOR),
+				'border_color' => Array('must' => 0,
+					'default' => '#000000',
 					'match' => MATCH_COLOR)),
 			'shape' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
@@ -388,14 +536,14 @@ class GlobalMapCfg {
 				'url_target' => Array('must' => 0,
 					'match' => MATCH_STRING_NO_SPACE),
 				'hover_url' => Array('must' => 0,
-									'match' => MATCH_STRING_URL)),
+					'match' => MATCH_STRING_URL),
+				'hover_delay' => Array('must' => 0,
+					'match' => MATCH_INTEGER)),
 			'template' => Array('type' => Array('must' => 0,
 					'match' => MATCH_OBJECTTYPE),
 				'name' => Array('must' => 1,
 					'match' => MATCH_STRING_NO_SPACE)));
 		
-		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::GlobalMapCfg()');
 	}
 	
 	/**
@@ -404,65 +552,99 @@ class GlobalMapCfg {
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getObjectDefaults() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::getObjectDefaults()');
 		$this->validConfig['host']['recognize_services']['default'] = $this->getValue('global', 0, 'recognize_services');
 		$this->validConfig['host']['only_hard_states']['default'] = $this->getValue('global', 0, 'only_hard_states');
 		$this->validConfig['host']['backend_id']['default'] = $this->getValue('global', 0, 'backend_id');
 		$this->validConfig['host']['iconset']['default'] = $this->getValue('global', 0, 'iconset');
+		$this->validConfig['host']['hover_menu']['default'] = $this->getValue('global', 0, 'hover_menu');
 		$this->validConfig['host']['hover_template']['default'] = $this->getValue('global', 0, 'hover_template');
+		$this->validConfig['host']['hover_timeout']['default'] = $this->getValue('global', 0, 'hover_timeout');
 		$this->validConfig['host']['hover_delay']['default'] = $this->getValue('global', 0, 'hover_delay');
 		$this->validConfig['host']['label_show']['default'] = $this->getValue('global', 0, 'label_show');
 		$this->validConfig['host']['label_x']['default'] = $this->getValue('global', 0, 'label_x');
 		$this->validConfig['host']['label_y']['default'] = $this->getValue('global', 0, 'label_y');
 		$this->validConfig['host']['label_width']['default'] = $this->getValue('global', 0, 'label_width');
 		$this->validConfig['host']['label_background']['default'] = $this->getValue('global', 0, 'label_background');
+		$this->validConfig['host']['label_border']['default'] = $this->getValue('global', 0, 'label_border');
 		$this->validConfig['host']['url_target']['default'] = $this->getValue('global', 0, 'url_target');
+		$this->validConfig['host']['hover_childs_show']['default'] = $this->getValue('global', 0, 'hover_childs_show');
+		$this->validConfig['host']['hover_childs_sort']['default'] = $this->getValue('global', 0, 'hover_childs_sort');
+		$this->validConfig['host']['hover_childs_order']['default'] = $this->getValue('global', 0, 'hover_childs_order');
+		$this->validConfig['host']['hover_childs_limit']['default'] = $this->getValue('global', 0, 'hover_childs_limit');
 		$this->validConfig['hostgroup']['recognize_services']['default'] = $this->getValue('global', 0, 'recognize_services');
 		$this->validConfig['hostgroup']['only_hard_states']['default'] = $this->getValue('global', 0, 'only_hard_states');
 		$this->validConfig['hostgroup']['backend_id']['default'] = $this->getValue('global', 0, 'backend_id');
 		$this->validConfig['hostgroup']['iconset']['default'] = $this->getValue('global', 0, 'iconset');
+		$this->validConfig['hostgroup']['hover_menu']['default'] = $this->getValue('global', 0, 'hover_menu');
 		$this->validConfig['hostgroup']['hover_template']['default'] = $this->getValue('global', 0, 'hover_template');
+		$this->validConfig['hostgroup']['hover_timeout']['default'] = $this->getValue('global', 0, 'hover_timeout');
 		$this->validConfig['hostgroup']['hover_delay']['default'] = $this->getValue('global', 0, 'hover_delay');
 		$this->validConfig['hostgroup']['label_show']['default'] = $this->getValue('global', 0, 'label_show');
 		$this->validConfig['hostgroup']['label_x']['default'] = $this->getValue('global', 0, 'label_x');
 		$this->validConfig['hostgroup']['label_y']['default'] = $this->getValue('global', 0, 'label_y');
 		$this->validConfig['hostgroup']['label_width']['default'] = $this->getValue('global', 0, 'label_width');
 		$this->validConfig['hostgroup']['label_background']['default'] = $this->getValue('global', 0, 'label_background');
+		$this->validConfig['hostgroup']['label_border']['default'] = $this->getValue('global', 0, 'label_border');
 		$this->validConfig['hostgroup']['url_target']['default'] = $this->getValue('global', 0, 'url_target');
+		$this->validConfig['hostgroup']['hover_childs_show']['default'] = $this->getValue('global', 0, 'hover_childs_show');
+		$this->validConfig['hostgroup']['hover_childs_sort']['default'] = $this->getValue('global', 0, 'hover_childs_sort');
+		$this->validConfig['hostgroup']['hover_childs_order']['default'] = $this->getValue('global', 0, 'hover_childs_order');
+		$this->validConfig['hostgroup']['hover_childs_limit']['default'] = $this->getValue('global', 0, 'hover_childs_limit');
 		$this->validConfig['service']['only_hard_states']['default'] = $this->getValue('global', 0, 'only_hard_states');
 		$this->validConfig['service']['backend_id']['default'] = $this->getValue('global', 0, 'backend_id');
 		$this->validConfig['service']['iconset']['default'] = $this->getValue('global', 0, 'iconset');
+		$this->validConfig['service']['hover_menu']['default'] = $this->getValue('global', 0, 'hover_menu');
 		$this->validConfig['service']['hover_template']['default'] = $this->getValue('global', 0, 'hover_template');
+		$this->validConfig['service']['hover_timeout']['default'] = $this->getValue('global', 0, 'hover_timeout');
 		$this->validConfig['service']['hover_delay']['default'] = $this->getValue('global', 0, 'hover_delay');
 		$this->validConfig['service']['label_show']['default'] = $this->getValue('global', 0, 'label_show');
 		$this->validConfig['service']['label_x']['default'] = $this->getValue('global', 0, 'label_x');
 		$this->validConfig['service']['label_y']['default'] = $this->getValue('global', 0, 'label_y');
 		$this->validConfig['service']['label_width']['default'] = $this->getValue('global', 0, 'label_width');
 		$this->validConfig['service']['label_background']['default'] = $this->getValue('global', 0, 'label_background');
+		$this->validConfig['service']['label_border']['default'] = $this->getValue('global', 0, 'label_border');
 		$this->validConfig['service']['url_target']['default'] = $this->getValue('global', 0, 'url_target');
+		$this->validConfig['service']['hover_childs_show']['default'] = $this->getValue('global', 0, 'hover_childs_show');
+		$this->validConfig['service']['hover_childs_sort']['default'] = $this->getValue('global', 0, 'hover_childs_sort');
+		$this->validConfig['service']['hover_childs_order']['default'] = $this->getValue('global', 0, 'hover_childs_order');
+		$this->validConfig['service']['hover_childs_limit']['default'] = $this->getValue('global', 0, 'hover_childs_limit');
 		$this->validConfig['servicegroup']['only_hard_states']['default'] = $this->getValue('global', 0, 'only_hard_states');
 		$this->validConfig['servicegroup']['backend_id']['default'] = $this->getValue('global', 0, 'backend_id');
 		$this->validConfig['servicegroup']['iconset']['default'] = $this->getValue('global', 0, 'iconset');
+		$this->validConfig['servicegroup']['hover_menu']['default'] = $this->getValue('global', 0, 'hover_menu');
 		$this->validConfig['servicegroup']['hover_template']['default'] = $this->getValue('global', 0, 'hover_template');
+		$this->validConfig['servicegroup']['hover_timeout']['default'] = $this->getValue('global', 0, 'hover_timeout');
 		$this->validConfig['servicegroup']['hover_delay']['default'] = $this->getValue('global', 0, 'hover_delay');
 		$this->validConfig['servicegroup']['label_show']['default'] = $this->getValue('global', 0, 'label_show');
 		$this->validConfig['servicegroup']['label_x']['default'] = $this->getValue('global', 0, 'label_x');
 		$this->validConfig['servicegroup']['label_y']['default'] = $this->getValue('global', 0, 'label_y');
 		$this->validConfig['servicegroup']['label_width']['default'] = $this->getValue('global', 0, 'label_width');
 		$this->validConfig['servicegroup']['label_background']['default'] = $this->getValue('global', 0, 'label_background');
+		$this->validConfig['servicegroup']['label_border']['default'] = $this->getValue('global', 0, 'label_border');
 		$this->validConfig['servicegroup']['url_target']['default'] = $this->getValue('global', 0, 'url_target');
+		$this->validConfig['servicegroup']['hover_childs_show']['default'] = $this->getValue('global', 0, 'hover_childs_show');
+		$this->validConfig['servicegroup']['hover_childs_sort']['default'] = $this->getValue('global', 0, 'hover_childs_sort');
+		$this->validConfig['servicegroup']['hover_childs_order']['default'] = $this->getValue('global', 0, 'hover_childs_order');
+		$this->validConfig['servicegroup']['hover_childs_limit']['default'] = $this->getValue('global', 0, 'hover_childs_limit');
 		$this->validConfig['map']['only_hard_states']['default'] = $this->getValue('global', 0, 'only_hard_states');
 		$this->validConfig['map']['iconset']['default'] = $this->getValue('global', 0, 'iconset');
+		$this->validConfig['map']['hover_menu']['default'] = $this->getValue('global', 0, 'hover_menu');
 		$this->validConfig['map']['hover_template']['default'] = $this->getValue('global', 0, 'hover_template');
+		$this->validConfig['map']['hover_timeout']['default'] = $this->getValue('global', 0, 'hover_timeout');
 		$this->validConfig['map']['hover_delay']['default'] = $this->getValue('global', 0, 'hover_delay');
 		$this->validConfig['map']['label_show']['default'] = $this->getValue('global', 0, 'label_show');
 		$this->validConfig['map']['label_x']['default'] = $this->getValue('global', 0, 'label_x');
 		$this->validConfig['map']['label_y']['default'] = $this->getValue('global', 0, 'label_y');
 		$this->validConfig['map']['label_width']['default'] = $this->getValue('global', 0, 'label_width');
 		$this->validConfig['map']['label_background']['default'] = $this->getValue('global', 0, 'label_background');
+		$this->validConfig['map']['label_border']['default'] = $this->getValue('global', 0, 'label_border');
 		$this->validConfig['map']['url_target']['default'] = $this->getValue('global', 0, 'url_target');
+		$this->validConfig['map']['hover_childs_show']['default'] = $this->getValue('global', 0, 'hover_childs_show');
+		$this->validConfig['map']['hover_childs_sort']['default'] = $this->getValue('global', 0, 'hover_childs_sort');
+		$this->validConfig['map']['hover_childs_order']['default'] = $this->getValue('global', 0, 'hover_childs_order');
+		$this->validConfig['map']['hover_childs_limit']['default'] = $this->getValue('global', 0, 'hover_childs_limit');
 		$this->validConfig['shape']['url_target']['default'] = $this->getValue('global', 0, 'url_target');
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getObjectDefaults()');
+		$this->validConfig['shape']['hover_delay']['default'] = $this->getValue('global', 0, 'hover_delay');
 	}
 	
 	/**
@@ -472,9 +654,7 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getBackground() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::getImage()');
 		$RET = new GlobalBackground($this->MAINCFG, $this->getValue('global', 0, 'map_image'));
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getImage()');
 		return $RET;
 	}
 	
@@ -485,7 +665,6 @@ class GlobalMapCfg {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function createMapConfig() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::createMapConfig()');
 		// does file exists?
 		if(!$this->checkMapConfigReadable(0)) {
 			if($this->MAINCFG->checkMapCfgFolderWriteable(1)) {
@@ -495,15 +674,12 @@ class GlobalMapCfg {
 				// set permissions
 				chmod($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg',0666);
 				
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::createMapConfig(): TRUE');
 					return TRUE;
 				} else {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::createMapConfig(): FALSE');
 					return FALSE;
 				}
 		} else {
 			// file exists & is readable
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::createMapConfig(): FALSE');
 			return FALSE;
 		}
 	}
@@ -515,20 +691,16 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function readMapConfig($onlyGlobal=0) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::readMapConfig('.$onlyGlobal.')');
 		if($this->name != '') {
 			if($this->checkMapConfigReadable(1)) {
 				$this->mapConfig = Array();
 				$types = Array('global'=>0,'host'=>0,'service'=>0,'hostgroup'=>0,'servicegroup'=>0,'map'=>0,'textbox'=>0,'shape'=>0,'template'=>0);
 				
 				// read file in array
-				if (DEBUG&&DEBUGLEVEL&2) debug('Start reading map configuration');
 				$file = file($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg');
-				if (DEBUG&&DEBUGLEVEL&2) debug('End reading map configuration');
 				$createArray = Array('allowed_user','allowed_for_config','use');
 				$l = 0;
 				
-				if (DEBUG&&DEBUGLEVEL&2) debug('Start parsing map configuration');
 				while(isset($file[$l]) && $file[$l] != '') {
 					// tested all of them, seems the runtime is nearly the same
 					// preg_match('/^(#|;)/',$file[$l])
@@ -537,7 +709,7 @@ class GlobalMapCfg {
 					if(!ereg('^(#|;)',$file[$l])) {
 						$defineCln = explode('{', $file[$l]);
 						$define = explode(' ',$defineCln[0]);
-						if(isset($define[1]) && array_key_exists(trim($define[1]),$this->validConfig)) {
+						if(isset($define[1]) && isset($this->validConfig[trim($define[1])])) {
 							$type = $types[$define[1]];
 							$l++;
 							$this->mapConfig[$define[1]][$type] = Array('type'=>$define[1]);
@@ -547,8 +719,8 @@ class GlobalMapCfg {
 									$entry[0] = trim($entry[0]);
 									if(isset($entry[1])) {
 										$entry[1] = trim($entry[1]);
-										if(in_array($entry[0],$createArray)) {
-											$this->mapConfig[$define[1]][$type][$entry[0]] = explode(',',str_replace(' ','',$entry[1]));
+										if(in_array($entry[0], $createArray)) {
+											$this->mapConfig[$define[1]][$type][$entry[0]] = explode(',',$entry[1]);
 										} else {
 											$this->mapConfig[$define[1]][$type][$entry[0]] = $entry[1];
 										}
@@ -562,7 +734,6 @@ class GlobalMapCfg {
 					}
 					$l++;
 				}
-				if (DEBUG&&DEBUGLEVEL&2) debug('End parsing map configuration');
 				
 				/**
 				 * The default values refer to global settings in the validConfig array - so they have to be 
@@ -584,18 +755,14 @@ class GlobalMapCfg {
 				
 				if($this->checkMapConfigIsValid(1)) {
 					$this->BACKGROUND = $this->getBackground();
-					if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::readMapConfig(): TRUE');
 					return TRUE;
 				} else {
-					if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::readMapConfig(): FALSE');
 					return FALSE;
 				}
 			} else {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::readMapConfig(): TRUE');
-				return FALSE;	
+				return FALSE;
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::readMapConfig(): TRUE');
 			return FALSE;
 		}
 	}
@@ -623,15 +790,15 @@ class GlobalMapCfg {
 	 */
 	function mergeTemplates() {
 		// Loop all objects
-		foreach($this->mapConfig AS $type => $elements) {
+		foreach($this->mapConfig AS $type => &$elements) {
 			// Except global and templates (makes no sense)
-			if($type != 'global' && $type != 'template') {
+			if($type != 'global') {
 				// Loop all objects of that type
-				foreach($elements AS $id => $element) {
+				foreach($elements AS $id => &$element) {
 					// Check for "use" value
 					if(isset($element['use']) && is_array($element['use'])) {
 						// loop all given templates
-						foreach($element['use'] AS $templateName) {
+						foreach($element['use'] AS &$templateName) {
 							if(isset($this->mapConfig['template'][$templateName]) && is_array($this->mapConfig['template'][$templateName])) {
 								// merge object array with template object array (except type and name atribute)
 								$tmpArray = $this->mapConfig['template'][$templateName];
@@ -655,18 +822,15 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function filterGlobal() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::filterGlobal()');
-		foreach($this->mapConfig AS $key => $val) {
+		foreach($this->mapConfig AS $key => &$val) {
 			if($key != 'global') {
 				unset($this->mapConfig[$key]);
 			}
 		}
 		
 		if(count($this->mapConfig) == 1) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::filterGlobal(): TRUE');
 			return TRUE;
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::filterGlobal(): FALSE');
 			return FALSE;
 		}
 	}
@@ -678,21 +842,17 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkMapConfigExists($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::checkMapConfigExists('.$printErr.')');
 		if($this->name != '') {
 			if(file_exists($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg')) {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigExists(): TRUE');
 				return TRUE;
 			} else {
 				if($printErr == 1) {
 					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
 					$FRONTEND->messageToUser('ERROR','mapCfgNotExists','MAP~'.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg');
 				}
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigExists(): FALSE');
 				return FALSE;
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigExists(): FALSE');
 			return FALSE;
 		}
 	}
@@ -705,21 +865,17 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkMapConfigReadable($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::checkMapConfigReadable('.$printErr.')');
 		if($this->name != '') {
 			if($this->checkMapConfigExists($printErr) && is_readable($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg')) {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigReadable(): TRUE');
 				return TRUE;
 			} else {
 				if($printErr == 1) {
 					$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
 					$FRONTEND->messageToUser('ERROR','mapCfgNotReadable','MAP='.$this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg');
 				}
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigReadable(): FALSE');
 				return FALSE;
 			}
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigReadable(): FALSE');
 			return FALSE;
 		}
 	}
@@ -732,14 +888,13 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function checkMapConfigIsValid($printErr) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::checkMapConfigIsValid('.$printErr.')');
 		// check given objects and attributes
-		foreach($this->mapConfig AS $type => $elements) {
+		foreach($this->mapConfig AS $type => &$elements) {
 			if($type != 'template') {
-				if(array_key_exists($type,$this->validConfig)) {
-					foreach($elements AS $id => $element) {
+				if(isset($this->validConfig[$type])) {
+					foreach($elements AS $id => &$element) {
 						// loop validConfig for checking: => missing "must" atributes
-						foreach($this->validConfig[$type] AS $key => $val) {
+						foreach($this->validConfig[$type] AS $key => &$val) {
 							if((isset($val['must']) && $val['must'] == '1')) {
 								// value is "must"
 								if(!isset($element[$key]) || $element[$key] == '') {
@@ -751,19 +906,19 @@ class GlobalMapCfg {
 						}
 						
 						// loop given elements for checking: => all given atributes valid
-						foreach($element AS $key => $val) {
+						foreach($element AS $key => &$val) {
 							// check for valid atributes
-							if(!array_key_exists($key,$this->validConfig[$type])) {
+							if(!isset($this->validConfig[$type][$key])) {
 								// unknown atribute
 								if($printErr == 1) {
 									$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
 									$FRONTEND->messageToUser('ERROR','unknownAttribute','MAPNAME~'.$this->name.',ATTRIBUTE~'.$key.',TYPE~'.$type);
 								}
-								if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigIsValid(): FALSE');
 								return FALSE;
 							} else {
-								// FIXME: Only match non array values at the moment
 								if(!is_array($val) && isset($this->validConfig[$type][$key]['match'])) {
+									// This is a string value
+									
 									// valid attribute, now check for value format
 									if(!preg_match($this->validConfig[$type][$key]['match'],$val)) {
 										
@@ -772,9 +927,23 @@ class GlobalMapCfg {
 											$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
 											$FRONTEND->messageToUser('ERROR','wrongValueFormatMap','MAP~'.$this->getName().',TYPE~'.$type.',ATTRIBUTE~'.$key);
 										}
-										if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigIsValid(): FALSE');
 										return FALSE;
 									}
+								} elseif(is_array($val) && isset($this->validConfig[$type][$key]['match'])) {
+									// This is an array
+									
+									//loop and check each element
+									foreach($val AS $key2 => &$val2) {
+										// check the value format
+										if(!preg_match($this->validConfig[$type][$key]['match'], $val2)) {
+											// wrong format
+											if($printErr) {
+												$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
+												$FRONTEND->messageToUser('ERROR','wrongValueFormatMap','MAP~'.$this->getName().',TYPE~'.$type.',ATTRIBUTE~'.$key);
+											}
+											return FALSE;
+										}
+									}
 								}
 							}
 						}
@@ -785,12 +954,10 @@ class GlobalMapCfg {
 						$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
 						$FRONTEND->messageToUser('ERROR','unknownObject','TYPE~'.$type);
 					}
-					if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigIsValid(): FALSE');
 					return FALSE;
 				}
 			}
 		}
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::checkMapConfigIsValid(): TRUE');
 		return TRUE;
 	}
 	
@@ -802,16 +969,28 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getDefinitions($type) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::getDefinitions('.$type.')');
 		if(isset($this->mapConfig[$type]) && count($this->mapConfig[$type]) > 0) {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getDefinitions(): Array(...)');
 			return $this->mapConfig[$type];
 		} else {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getDefinitions(): Array()');
 			return Array();
 		}
 	}
 	
+	/**
+	 * Gets the last modification time of the configuration file
+	 *
+	 * @return	Integer Unix timestamp with last modification time
+	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function getFileModificationTime() {
+		if($this->checkMapConfigReadable(1)) {
+			$time = filemtime($this->MAINCFG->getValue('paths', 'mapcfg').$this->name.'.cfg');
+			return $time;
+		} else {
+			return FALSE;
+		}
+	}
+	
 	/**
 	 * Deletes an element of the specified type to the config array
 	 *
@@ -821,9 +1000,7 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function deleteElement($type,$id) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::deleteElement('.$type.','.$id.')');
 		$this->mapConfig[$type][$id] = '';
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::deleteElement()');
 		return TRUE;
 	}
 	
@@ -836,10 +1013,8 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function addElement($type,$properties) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::addElement('.$type.',Array(...))');
 		//$elementId = (count($this->getDefinitions($type))+1);
 		$this->mapConfig[$type][] = $properties;
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::addElement(): '.(count($this->mapConfig[$type])-1));
 		return count($this->mapConfig[$type])-1;
 	}
 	
@@ -854,9 +1029,7 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function setValue($type, $id, $key, $value) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::setValue('.$type.','.$id.','.$key.','.$value.')');
 		$this->mapConfig[$type][$id][$key] = $value;
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::setValue(): TRUE');
 		return TRUE;
 	}
 	
@@ -871,13 +1044,10 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getValue($type, $id, $key, $ignoreDefault=FALSE) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::getValue('.$type.','.$id.','.$key.','.$ignoreDefault.')');
-		if(isset($this->mapConfig[$type][$id]) && is_array($this->mapConfig[$type][$id]) && array_key_exists($key,$this->mapConfig[$type][$id]) && $this->mapConfig[$type][$id][$key] != '') {
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getValue(): '.$this->mapConfig[$type][$id][$key]);
+		if(isset($this->mapConfig[$type][$id]) && is_array($this->mapConfig[$type][$id]) && isset($this->mapConfig[$type][$id][$key]) && $this->mapConfig[$type][$id][$key] != '') {
 			return $this->mapConfig[$type][$id][$key];
 		} elseif(!$ignoreDefault) {
 			if(isset($this->validConfig[$type][$key]['default'])) {
-				if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getValue(): '.$this->validConfig[$type][$key]['default']);
 				return $this->validConfig[$type][$key]['default'];
 			}
 		}
@@ -890,9 +1060,17 @@ class GlobalMapCfg {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getName() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMapCfg::getName()');
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMapCfg::getName(): '.$this->name);
 		return $this->name;	
 	}
+	
+	/**
+	 * Gets the map alias
+	 *
+	 * @return	String	Map alias
+	 * @author 	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function getAlias() {
+		return $this->getValue('global', 0, 'alias');	
+	}
 }
 ?>
