@@ -1,6 +1,29 @@
 <?php
-/** 
- * Class for adding/modify objects on maps
+/*****************************************************************************
+ *
+ * WuiAddModify.php - Class for adding/modifying objects on the map
+ *
+ * Copyright (c) 2004-2008 NagVis Project (Contact: lars@vertical-visions.de)
+ *
+ * License:
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *****************************************************************************/
+ 
+/**
+ * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class WuiAddModify extends GlobalPage {
 	var $MAINCFG;
@@ -19,7 +42,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function WuiAddModify(&$MAINCFG,&$MAPCFG,$prop) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::WuiAddModify(&$MAINCFG,&$MAPCFG,$prop)');
 		$this->MAINCFG = &$MAINCFG;
 		$this->MAPCFG = &$MAPCFG;
 		$this->prop = $prop;
@@ -30,13 +52,12 @@ class WuiAddModify extends GlobalPage {
 		
 		$prop = Array('title'=>$MAINCFG->getValue('internal', 'title'),
 					  'cssIncludes'=>Array('./includes/css/wui.css'),
-					  'jsIncludes'=>Array('./includes/js/addmodify.js',
+					  'jsIncludes'=>Array('../nagvis/includes/js/ajax.js','./includes/js/addmodify.js',
 					  					  './includes/js/ajax.js',
 					  					  './includes/js/wui.js'),
 					  'extHeader'=>Array(''),
 					  'allowedUsers' => Array('EVERYONE'));
 		parent::GlobalPage($MAINCFG,$prop,'wui:addModify');
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::WuiAddModify()');
 	}
 	
 	/**
@@ -45,9 +66,8 @@ class WuiAddModify extends GlobalPage {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getForm() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getForm()');
 		// Inititalize language for JS, Write JS Array for config validation
-		$this->addBodyLines($this->parseJs(array_merge($this->getJsLang(),$this->getJsValidConfig())));
+		$this->addBodyLines($this->parseJs($this->getJsLang()));
 		
 		$this->FORM = new GlobalForm(Array('name'=>'addmodify',
 			'id'=>'addmodify',
@@ -61,7 +81,6 @@ class WuiAddModify extends GlobalPage {
 		$this->addBodyLines($this->FORM->getSubmitLine($this->LANG->getLabel('save')));
 		$this->addBodyLines($this->FORM->closeForm());
 		$this->addBodyLines($this->parseJs($this->resizeWindow(410,($this->propCount*30+80))));
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getForm()');
 	}
 	
 	/**
@@ -71,7 +90,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function fillFields() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::fillFields()');
 		$ret = Array();
 		
 		switch($this->prop['action']) {
@@ -113,7 +131,6 @@ class WuiAddModify extends GlobalPage {
 			break;
 		}
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::fillFields(): Array(JS)');
 		return $ret;
 	}
 	
@@ -124,7 +141,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getFields() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getFields()');
 		$ret = Array();
 		$ret = array_merge($ret,$this->FORM->getHiddenField('type',$this->prop['type']));
 		$ret = array_merge($ret,$this->FORM->getHiddenField('id',$this->prop['id']));
@@ -135,24 +151,24 @@ class WuiAddModify extends GlobalPage {
 		foreach($this->MAPCFG->validConfig[$this->prop['type']] as $propname => $prop) {
 			if($propname == "iconset") {
 				// treat the special case of iconset, which will display a listbox instead of the normal textbox
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getIconsets(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getIconsets(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif($this->prop['type'] == 'shape' && $propname == "icon") {
 				// treat the special case of icon when type is shape, which will display a listbox instead of the normal textbox
 				if(preg_match("/^\[(.*)\]$/",$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$match) > 0) {
-					$ret = array_merge($ret,$this->FORM->getInputLine($propname,$propname,$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+					$ret = array_merge($ret,$this->FORM->getInputLine($propname,$propname,$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				} else {
-					$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getShapes(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+					$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getShapes(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				}
 				$this->propCount++;
 			}  elseif($propname == "map_image") {
 				// treat the special case of map_image, which will display a listbox instead of the normal textbox
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getMapImages(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getMapImages(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif($propname == "recognize_services" || $propname == "only_hard_states" || $propname == "label_show" || $propname == "usegdlibs") {
 				// treat the special case of recognize_services, which will display a "yes/no" listbox instead of the normal textbox
 				$opt = Array(Array('label' => $this->LANG->getLabel('yes'),'value'=>'1'),Array('label' => $this->LANG->getLabel('no'),'value'=>'0'));
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$opt,$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$opt,$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif($propname == "backend_id") {
 				if($this->prop['type'] == 'service') {
@@ -162,22 +178,22 @@ class WuiAddModify extends GlobalPage {
 					$field = $this->prop['type'] . '_name';
 					$type = $this->prop['type'];
 				}
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getBackends(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],"getObjects(this.value,'".$type."','".$field."','".$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE)."');"));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getBackends(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],"getObjects(this.value,'".$type."','".$field."','".$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE)."');validateMapConfigFieldValue(this);"));
 				$this->propCount++;
 			} elseif($propname == "line_type") {
 				// treat the special case of line_type, which will display a listbox showing the different possible shapes for the line
 				$opt = Array(Array('label' => '------><------','value' => '0'),Array('label' => '-------------->','value'=>'1'));
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$opt,substr($this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),1,1),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$opt,substr($this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),1,1),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif($propname == "hover_template") {
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getHoverTemplates(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getHoverTemplates(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif($propname == "header_template") {
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getHeaderTemplates(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getHeaderTemplates(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif($propname == "map_name") {
 				// treat the special case of map_name, which will display a listbox instead of the normal textbox
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getMaps(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,$this->getMaps(),$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE),$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			} elseif(($propname == 'host_name' || $propname == 'hostgroup_name' || $propname == 'servicegroup_name')) {
 				$backendId = $this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],'backend_id');
@@ -186,13 +202,17 @@ class WuiAddModify extends GlobalPage {
 					$ret[] = "<script>getServices('".$backendId."','".$this->prop['type']."','".$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE)."','service_description','".$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],'service_description',TRUE)."');</script>";
 				}
 				if($propname == 'host_name') {
-					$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must'],"getServices('".$backendId."','".$this->prop['type']."',this.value,'service_description','".$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE)."');"));
+					if($this->prop['type'] == 'service') {
+						$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must'],"getServices('".$backendId."','".$this->prop['type']."',this.value,'service_description','".$this->MAPCFG->getValue($this->prop['type'],$this->prop['id'],$propname,TRUE)."');validateMapConfigFieldValue(this)"));
+					} else {
+						$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must'],'validateMapConfigFieldValue(this)'));
+					}
 				} else {
-					$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must']));
+					$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must'],'validateMapConfigFieldValue(this)'));
 				}
 				$this->propCount++;
 			} elseif($propname == 'service_description') {
-				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getSelectLine($propname,$propname,Array(),'',$prop['must'],'validateMapConfigFieldValue(this)'));
 			} elseif($propname == 'type') {
 				// Do nothing, type is only internal
 			} else {
@@ -203,12 +223,11 @@ class WuiAddModify extends GlobalPage {
 					$value = implode(',',$value);
 				}
 				
-				$ret = array_merge($ret,$this->FORM->getInputLine($propname,$propname,$value,$prop['must']));
+				$ret = array_merge($ret,$this->FORM->getInputLine($propname,$propname,$value,$prop['must'],'validateMapConfigFieldValue(this)'));
 				$this->propCount++;
 			}
 		}
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getFields(): Array(HTML)');
 		return $ret;
 	}
 	
@@ -219,7 +238,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getBackends() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getBackends()');
 		$ret = Array();
 		foreach($this->MAINCFG->config AS $sec => $var) {
 			if(preg_match("/^backend_/i", $sec)) {
@@ -227,7 +245,6 @@ class WuiAddModify extends GlobalPage {
 			}
 		}
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getBackends(): Array(...)');
 		return $ret;
 	}
 	
@@ -238,7 +255,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getHoverTemplates() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getHoverTemplates()');
 		$files = Array();
 		
 		if($handle = opendir($this->MAINCFG->getValue('paths', 'hovertemplate'))) {
@@ -254,7 +270,6 @@ class WuiAddModify extends GlobalPage {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getHoverTemplates(): Array(...)');
 		return $files;
 	}
 	
@@ -265,7 +280,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getHeaderTemplates() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiEditMainCfg::getHeaderTemplates()');
 		$files = Array();
 		
 		if ($handle = opendir($this->MAINCFG->getValue('paths', 'headertemplate'))) {
@@ -281,7 +295,6 @@ class WuiAddModify extends GlobalPage {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiEditMainCfg::getHeaderTemplates(): Array(...)');
 		return $files;
 	}
 	
@@ -292,7 +305,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getShapes() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getShapres()');
 		$files = Array();
 		
 		if ($handle = opendir($this->MAINCFG->getValue('paths', 'shape'))) {
@@ -308,7 +320,6 @@ class WuiAddModify extends GlobalPage {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getShapes(): Array(...)');
 		return $files;
 	}
 	
@@ -319,7 +330,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getIconsets() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getIconsets()');
 		$files = Array();
 		
 		if ($handle = opendir($this->MAINCFG->getValue('paths', 'icon'))) {
@@ -335,7 +345,6 @@ class WuiAddModify extends GlobalPage {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getIconsets(): Array(...)');
 		return $files;
 	}
 	
@@ -346,7 +355,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getMaps() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getMaps()');
 		$files = Array();
 		
 		if ($handle = opendir($this->MAINCFG->getValue('paths', 'mapcfg'))) {
@@ -362,7 +370,6 @@ class WuiAddModify extends GlobalPage {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getMaps(): Array(...)');
 		return $files;
 	}
 	
@@ -373,12 +380,11 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getMapImages() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getMapImages()');
 		$files = Array();
 		
 		if ($handle = opendir($this->MAINCFG->getValue('paths', 'map'))) {
  			while (false !== ($file = readdir($handle))) {
-				if ($file != "." && $file != ".." && preg_match('/.png$/', $file)) {
+				if ($file != "." && $file != ".." && preg_match('/.png$/i', $file)) {
 					$files[] = $file;
 				}				
 			}
@@ -389,7 +395,6 @@ class WuiAddModify extends GlobalPage {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getMapImages(): Array(...)');
 		return $files;
 	}
 	
@@ -400,7 +405,6 @@ class WuiAddModify extends GlobalPage {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getJsLang() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getJsLang()');
 		$ret = Array();
 		$ret[] = 'var lang = Array();';
 		$ret[] = 'var user = \''.$this->MAINCFG->getRuntimeValue('user').'\';';
@@ -416,58 +420,6 @@ class WuiAddModify extends GlobalPage {
 		$ret[] = 'lang[\'lineTypeNotSelectedY\'] = \''.$this->LANG->getMessageText('lineTypeNotSelected','','COORD=Y').'\';';
 		$ret[] = 'lang[\'loopInMapRecursion\'] = \''.$this->LANG->getMessageText('loopInMapRecursion').'\';';
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getJsLang(): Array(JS)');
-		return $ret;	
-	}
-	
-	/**
-	 * Gets the validConfig array in javascript format
-	 *
-	 * @return	Array JS
-	 * @author 	Lars Michelsen <lars@vertical-visions.de>
-     */
-	function getJsValidConfig() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiAddModify::getJsValidConfig()');
-		$ret = Array();
-		
-		$sRet = "var validConfig = { \n";
-		$i = 0;
-		foreach($this->MAPCFG->validConfig AS $type => $arr) {
-			if($i != 0) {
-				$sRet .= ", \n";	
-			}
-			$sRet .= '\''.$type.'\': { ';
-			$a = 0;
-			foreach($arr AS $key => $opt) {
-				if($a != 0) {
-					$sRet .= ", \n\t";	
-				}
-				if($key != 'type') {
-					$sRet .= '\''.$key.'\': { ';
-						$e = 0;
-						foreach($opt AS $var => $val) {
-							if($e != 0) {
-								$sRet .= ", \n\t\t";	
-							}
-							$sRet .= '\''.$var.'\': ';
-							if(is_numeric($val)) {
-								$sRet .= $val;
-							} else {
-								$sRet .= '\''.$val.'\'';
-							}
-							$e++;
-						}
-					$sRet .= ' }';
-					$a++;
-				}
-			}
-			$sRet .= "\n}";
-			$i++;
-		}
-		$sRet .= ' };';
-		$ret[] = $sRet;
-		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiAddModify::getJsValidConfig(): Array(JS)');
 		return $ret;
 	}
 }
