@@ -1,6 +1,29 @@
 <?php
-/** 
- * Class for printing the map in NagVis Wui
+/*****************************************************************************
+ *
+ * WuiMap.php - Class for printing the maps in WUI
+ *
+ * Copyright (c) 2004-2008 NagVis Project (Contact: lars@vertical-visions.de)
+ *
+ * License:
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *****************************************************************************/
+ 
+/**
+ * @author	Lars Michelsen <lars@vertical-visions.de>
  */
 class WuiMap extends GlobalMap {
 	var $MAINCFG;
@@ -20,7 +43,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function WuiMap(&$MAINCFG,&$MAPCFG,&$LANG) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::WuiMap(&$MAINCFG,&$MAPCFG,&$LANG)');
 		$this->MAINCFG = &$MAINCFG;
 		$this->MAPCFG = &$MAPCFG;
 		$this->LANG = &$LANG;
@@ -31,7 +53,6 @@ class WuiMap extends GlobalMap {
 		
 		$this->loadPermissions();
 		$this->objects = $this->getMapObjects(1);
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::WuiMap()');
 	}
 	
 	/**
@@ -40,7 +61,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function loadPermissions() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::LoadPermissions()');
 		$mapOptions = '[ ';
 		$a = 0;
 		foreach($this->getMaps() AS $map) {
@@ -109,7 +129,6 @@ class WuiMap extends GlobalMap {
 		}
 		$mapOptions .= ' ]';
 		$this->MAINCFG->setRuntimeValue('mapOptions',$mapOptions);
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::LoadPermissions()');
 	}
 	
 	/**
@@ -119,16 +138,14 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseMap() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::parseMap()');
 		$ret = Array();
 		$ret = array_merge($ret,$this->getBackground());
-		$ret = array_merge($ret,$this->parseJs(array_merge($this->getJsGraphicObj(),$this->getJsLang())));
+		$ret = array_merge($ret,$this->parseJs($this->getJsGraphicObj()."\n".$this->getJsLang()."\n".$this->getJsValidMainConfig()."\n".$this->getJsValidMapConfig()));
 		$ret = array_merge($ret,$this->parseObjects());
 		$ret = array_merge($ret,$this->parseInvisible());
 		$ret = array_merge($ret,$this->makeObjectsMoveable());
 		$ret = array_merge($ret,Array("<script type=\"text/javascript\" src=\"./includes/js/wz_tooltip.js\"></script>"));
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::parseMap(): Array(HTML)');
 		return $ret;
 	}
 	
@@ -139,7 +156,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getBackground() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::getBackground('.$type.')');
 		$style = '';
 		if($this->MAPCFG->getName() != '') {
 			$src = $this->MAINCFG->getValue('paths', 'htmlmap').$this->MAPCFG->BACKGROUND->getFileName();
@@ -148,24 +164,21 @@ class WuiMap extends GlobalMap {
 			$style = 'width:800px; height:600px;';
 		}
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getBackground(): Array(...)');
 		return $this->getBackgroundHtml($src, $style);
 	}
 	
 	/**
 	 * Gets JS graphic options
 	 *
-	 * @return	Array Html
+	 * @return	String Html
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getJsGraphicObj() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::getJsGraphicObj()');
-		$ret = Array();
-		$ret[] = "myshape_background = new jsGraphics('mymap');";
-		$ret[] = "myshape_background.setColor('#FF0000');";
-		$ret[] = "myshape_background.setStroke(1);\n";
+		$ret = '';
+		$ret .= "myshape_background = new jsGraphics('mymap');\n";
+		$ret .= "myshape_background.setColor('#FF0000');\n";
+		$ret .= "myshape_background.setStroke(1);\n";
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getJsGraphicObj(): Array(JS)');
 		return $ret;
 	}
 	
@@ -176,14 +189,12 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function makeObjectsMoveable() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::makeObjectsMoveable()');
 		$ret = Array();
 		
 		if(strlen($this->moveable) != 0) {
 			$ret = $this->parseJs("SET_DHTML(TRANSPARENT,CURSOR_HAND,".substr($this->moveable,0,strlen($this->moveable)-1).");\n");
 		}
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::makeObjectsMoveable(): Array(HTML)');
 		return $ret;
 	}
 	
@@ -195,7 +206,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseJs($js) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::parseJs(Array/String $js)');
 		$ret = Array();
 		
 		$ret[] = "<script type=\"text/javascript\" language=\"JavaScript\">";
@@ -208,7 +218,6 @@ class WuiMap extends GlobalMap {
 		$ret[] = "//-->";
 		$ret[] = "</script>";
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::makeObjectsMoveable(): Array(HTML)');
 		return $ret;
 	}
 	
@@ -219,7 +228,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseObjects() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::parseObjects()');
 		$ret = Array();
 		
 		foreach($this->objects AS $var => $obj) {
@@ -257,22 +265,63 @@ class WuiMap extends GlobalMap {
 				break;	
 			}
 		}
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::parseObjects(): Array(HTML)');
 		return $ret;
 	}
 	
 	/**
-	 * Adds paths to the icon
+	 * Create a position for a icon on the map
+	 *
+	 * @param	Array	Array with object properties
+	 * @return	Array	Array with object properties
+	 * @author	Michael Luebben <michael_luebben@web.de>
+	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function fixIcon(&$obj) {
+		$obj = $this->getIconPaths($obj);
+		
+		if($obj['type'] == 'shape' && preg_match('/^\[(.*)\]$/',$obj['icon'],$match) > 0) {
+			$obj['icon'] = $match[1];
+		} else {
+			if(!isset($obj['path']) || $obj['path'] == '') {
+				$imgPath = $obj['icon'];
+			} else {
+				$imgPath = $obj['path'].$obj['icon'];
+			}
+			
+			if(!file_exists($imgPath)) {
+				$FRONTEND = new GlobalPage($this->MAINCFG,Array('languageRoot'=>'global:global'));
+				$FRONTEND->messageToUser('WARNING','iconNotExists','IMGPATH~'.$imgPath);
+				
+				$obj['path'] = $this->MAINCFG->getValue('paths', 'icon');
+				$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlicon');
+				$obj['icon'] = '20x20.gif';
+			}
+		}
+		
+		return $obj;
+	}
+	
+	/**
+	 * Gets the paths to the icon
 	 *
 	 * @param	Array	$obj	Array with object informations
 	 * @return	Array	Array with object informations
 	 * @author	Lars Michelsen <lars@vertical-visions.de>
 	 */
-	function fixIcon(&$obj) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::fixIcon()');
-		$ret = parent::fixIcon($this->getIconPaths($obj));
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::fixIcon(): Array(...)');
-		return $ret;
+	function getIconPaths(&$obj) {
+		if($obj['type'] == 'shape') {
+			if(preg_match('/^\[(.*)\]$/',$obj['icon'],$match) > 0) {
+				$obj['path'] = '';
+				$obj['htmlPath'] = '';
+			} else {
+				$obj['path'] = $this->MAINCFG->getValue('paths', 'shape');
+				$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlshape');
+			}
+		} else {
+			$obj['path'] = $this->MAINCFG->getValue('paths', 'icon');
+			$obj['htmlPath'] = $this->MAINCFG->getValue('paths', 'htmlicon');
+		}
+		return $obj;
 	}
 	
 	/**
@@ -282,7 +331,6 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function parseIcon(&$obj) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::parseIcon()');
 		$ret = Array();
 				
 		if($obj['type'] == 'service') {
@@ -295,7 +343,63 @@ class WuiMap extends GlobalMap {
 		$ret[] = "\t\t<img src=\"".$obj['htmlPath'].$obj['icon']."\" alt=\"".$obj['type']."_".$obj['id']."\" ".$this->infoBox($obj).">";
 		$ret[] = "</div>";
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::fixIcon(): Array(HTML)');
+		return $ret;
+	}
+	
+	/**
+	 * Parses the HTML-Code of a label
+	 *
+	 * @param	Array	$obj		Array with object informations
+	 * @param	String	$base		Array with object informations
+	 * @param	Boolean	$link		Add a link to the icon
+	 * @param	Boolean	$hoverMenu	Add a hover menu to the icon
+	 * @return	String	String with Html Code
+	 * @author	Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function parseLabel(&$obj) {
+		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMap::parseLabel(&$obj)');
+		$relative = 0;
+		
+		if($obj['type'] == 'service') {
+			$name = 'host_name';
+		} else {
+			$name = $obj['type'] . '_name';
+		}
+		
+		// If there is a presign it should be relative to the objects x/y
+		if(preg_match('/^(\+|\-)/',$obj['label_x'])) {
+			$obj['label_x'] = $obj['x'] + $obj['label_x'];
+			$relative = 1;
+		}
+		if(preg_match('/^(\+|\-)/',$obj['label_y'])) {
+			$obj['label_y'] = $obj['y'] + $obj['label_y'];
+			$relative = 1;
+		}
+		
+		// If no x/y coords set, fallback to object x/y
+		if(!isset($obj['label_x']) || $obj['label_x'] == '' || $obj['label_x'] == 0) {
+			$obj['label_x'] = $obj['x'];
+		}
+		if(!isset($obj['label_y']) || $obj['label_y'] == '' || $obj['label_y'] == 0) {
+			$obj['label_y'] = $obj['y'];
+		}
+		
+		if(isset($obj['label_width']) && $obj['label_width'] != 'auto') {
+			$obj['label_width'] .= 'px';	
+		}
+		
+		//
+		if($relative == 1) {
+			$id = '"id="rel_label_'.$obj['type'].'_'.$obj['id'].'"';
+		} else {
+			$id = '"id="abs_label_'.$obj['type'].'_'.$obj['id'].'"';
+		}
+		
+		$ret  = '<div '.$id.' class="object_label" style="background:'.$obj['label_background'].';border-color:'.$obj['label_border'].';left:'.$obj['label_x'].'px;top:'.$obj['label_y'].'px;width:'.$obj['label_width'].';z-index:'.($obj['z']+1).';overflow:visible;">';
+		$ret .= '<span>'.$obj['label_text'].'</span>';
+		$ret .= '</div>';
+		
+		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMap::parseLabel(): HTML String');
 		return $ret;
 	}
 	
@@ -307,7 +411,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getMapObjects($mergeWithGlobals=1) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMap::getMapObjects('.$mergeWithGlobals.')');
 		$objects = Array();
 		
 		$objects = array_merge($objects,$this->getObjectsOfType('map',$mergeWithGlobals));
@@ -318,7 +421,6 @@ class WuiMap extends GlobalMap {
 		$objects = array_merge($objects,$this->getObjectsOfType('textbox',$mergeWithGlobals));
 		$objects = array_merge($objects,$this->getObjectsOfType('shape',$mergeWithGlobals));
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMap::getMapObjects(): Array(...)');
 		return $objects;
 	}
 	
@@ -331,7 +433,6 @@ class WuiMap extends GlobalMap {
 	 * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
 	function getObjectsOfType($type,$mergeWithGlobals=1) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method GlobalMap::getObjectsOfType('.$type.','.$mergeWithGlobals.')');
 		// object array
 		$objects = Array();
 		
@@ -344,7 +445,6 @@ class WuiMap extends GlobalMap {
 		
 		if(is_array($objs = $this->MAPCFG->getDefinitions($type))){
 			foreach($objs AS $index => $obj) {
-				if (DEBUG&&DEBUGLEVEL&2) debug('Start object of type: '.$type);
 				// workaround
 				$obj['id'] = $index;
 				
@@ -366,14 +466,43 @@ class WuiMap extends GlobalMap {
 				
 				// add object to array of objects
 				$objects[] = $obj;
-				if (DEBUG&&DEBUGLEVEL&2) debug('End object of type: '.$type);
 			}
 			
-			if (DEBUG&&DEBUGLEVEL&1) debug('End method GlobalMap::getObjectsOfType(): Array(...)');
 			return $objects;
 		}
 	}
 	
+	/**
+	 * Searches the icon for an object
+	 *
+	 * @param	Array	$obj	Array with object properties
+	 * @return	String	Name of the icon
+	 * @author Michael Luebben <michael_luebben@web.de>
+	 * @author Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function getIcon(&$obj) {
+		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::getIcon(&$obj)');
+		
+		switch($obj['type']) {
+			case 'service':
+			case 'servicegroup':
+				$icon = $obj['iconset'].'_ok.png';
+			break;
+			default:
+					$icon = $obj['iconset'].'_up.png';
+			break;
+		}
+		
+		//replaced: if(file_exists($this->MAINCFG->getValue('paths', 'icon').$icon)) {
+		if(@fclose(@fopen($this->MAINCFG->getValue('paths', 'icon').$icon,'r'))) {
+			if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getIcon(): '.$icon);
+			return $icon;
+		} else {
+			if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getIcon(): '.$obj['iconset'].'_error.png');
+			return $obj['iconset'].'_error.png';
+		}
+	}
+	
 	/**
 	 * Create a Comment-Textbox
 	 *
@@ -381,7 +510,6 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function textBox(&$obj) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::textBox(&$obj)');
 		$ret = Array();
 		
 		if(isset($obj['w'])) {
@@ -394,7 +522,6 @@ class WuiMap extends GlobalMap {
 		$ret[] = "\t<span>".$obj['text']."</span>";
 		$ret[] = "</div>";
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::textBox(): Array(HTML)');
 		return $ret;	
 	}
 	
@@ -405,7 +532,6 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
      */
 	function infoBox(&$obj) {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::infoBox(&$obj)');
 		if($obj['type'] == 'service') {
 			$name = 'host_name';
 		} else {
@@ -449,7 +575,6 @@ class WuiMap extends GlobalMap {
 		
 		$info = "onmouseover=\"this.T_DELAY=1000;this.T_STICKY=true;this.T_OFFSETX=6;this.T_OFFSETY=6;this.T_WIDTH=200;this.T_FONTCOLOR='#000000';this.T_BORDERCOLOR='#000000';this.T_BGCOLOR='#FFFFFF';this.T_STATIC=true;this.T_TITLE='<b>".$this->LANG->getLabel($obj['type'])."</b>';return escape('".$tooltipText."');\"";
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::infoBox(): HTML');
 		return $info;
 	}
 	
@@ -460,12 +585,11 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
      */
 	function getMaps() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::getMaps()');
 		$files = Array();
 		
 		if ($handle = opendir($this->MAINCFG->getValue('paths', 'mapcfg'))) {
  			while (false !== ($file = readdir($handle))) {
-				if(preg_match('/^.+\.cfg$/', $file)) {
+				if(preg_match('/^.+\.cfg$/', $file) && $file != '__automap.cfg') {
 					$files[] = substr($file,0,strlen($file)-4);
 				}				
 			}
@@ -476,53 +600,73 @@ class WuiMap extends GlobalMap {
 		}
 		closedir($handle);
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getMaps(): Array(...)');
 		return $files;
 	}
-		
+	
 	/**
 	 * Parses the needed language strings to javascript
 	 *
-	 * @return	Array Html
+	 * @return	String Html
 	 * @author Lars Michelsen <lars@vertical-visions.de>
 	 */
 	function getJsLang() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::getJsLang()');
-		$ret = Array();
-		$ret[] = 'var langMenu = Array();';
-		$ret[] = 'langMenu[\'save\'] = \''.$this->LANG->getLabel('save').'\';';
-		$ret[] = 'langMenu[\'restore\'] = \''.$this->LANG->getLabel('restore').'\';';
-		$ret[] = 'langMenu[\'properties\'] = \''.$this->LANG->getLabel('properties').'\';';
-		$ret[] = 'langMenu[\'addObject\'] = \''.$this->LANG->getLabel('addObject').'\';';
-		$ret[] = 'langMenu[\'nagVisConfig\'] = \''.$this->LANG->getLabel('nagVisConfig').'\';';
-		$ret[] = 'langMenu[\'help\'] = \''.$this->LANG->getLabel('help').'\';';
-		$ret[] = 'langMenu[\'open\'] = \''.$this->LANG->getLabel('open').'\';';
-		$ret[] = 'langMenu[\'openInNagVis\'] = \''.$this->LANG->getLabel('openInNagVis').'\';';
-		$ret[] = 'langMenu[\'manageMaps\'] = \''.$this->LANG->getLabel('manageMaps').'\';';
-		$ret[] = 'langMenu[\'manageBackends\'] = \''.$this->LANG->getLabel('manageBackends').'\';';
-		$ret[] = 'langMenu[\'manageBackgrounds\'] = \''.$this->LANG->getLabel('manageBackgrounds').'\';';
-		$ret[] = 'langMenu[\'manageShapes\'] = \''.$this->LANG->getLabel('manageShapes').'\';';
-		$ret[] = 'langMenu[\'icon\'] = \''.$this->LANG->getLabel('icon').'\';';
-		$ret[] = 'langMenu[\'line\'] = \''.$this->LANG->getLabel('line').'\';';
-		$ret[] = 'langMenu[\'special\'] = \''.$this->LANG->getLabel('special').'\';';
-		$ret[] = 'langMenu[\'host\'] = \''.$this->LANG->getLabel('host').'\';';
-		$ret[] = 'langMenu[\'service\'] = \''.$this->LANG->getLabel('service').'\';';
-		$ret[] = 'langMenu[\'hostgroup\'] = \''.$this->LANG->getLabel('hostgroup').'\';';
-		$ret[] = 'langMenu[\'servicegroup\'] = \''.$this->LANG->getLabel('servicegroup').'\';';
-		$ret[] = 'langMenu[\'map\'] = \''.$this->LANG->getLabel('map').'\';';
-		$ret[] = 'langMenu[\'textbox\'] = \''.$this->LANG->getLabel('textbox').'\';';
-		$ret[] = 'langMenu[\'shape\'] = \''.$this->LANG->getLabel('shape').'\';';
-		$ret[] = 'langMenu[\'manage\'] = \''.$this->LANG->getLabel('manage').'\';';
-		$ret[] = 'var lang = Array();';
-		$ret[] = 'lang[\'clickMapToSetPoints\'] = \''.$this->LANG->getMessageText('clickMapToSetPoints').'\';';
-		$ret[] = 'lang[\'confirmDelete\'] = \''.$this->LANG->getMessageText('confirmDelete').'\';';
-		$ret[] = 'lang[\'confirmRestore\'] = \''.$this->LANG->getMessageText('confirmRestore').'\';';
-		$ret[] = 'lang[\'unableToDeleteMap\'] = \''.$this->LANG->getMessageText('unableToDeleteMap').'\';';
+		$ret = '';
+		$ret .= 'var langMenu = Array();';
+		$ret .= 'langMenu[\'save\'] = \''.$this->LANG->getLabel('save').'\';';
+		$ret .= 'langMenu[\'restore\'] = \''.$this->LANG->getLabel('restore').'\';';
+		$ret .= 'langMenu[\'properties\'] = \''.$this->LANG->getLabel('properties').'\';';
+		$ret .= 'langMenu[\'addObject\'] = \''.$this->LANG->getLabel('addObject').'\';';
+		$ret .= 'langMenu[\'nagVisConfig\'] = \''.$this->LANG->getLabel('nagVisConfig').'\';';
+		$ret .= 'langMenu[\'help\'] = \''.$this->LANG->getLabel('help').'\';';
+		$ret .= 'langMenu[\'open\'] = \''.$this->LANG->getLabel('open').'\';';
+		$ret .= 'langMenu[\'openInNagVis\'] = \''.$this->LANG->getLabel('openInNagVis').'\';';
+		$ret .= 'langMenu[\'manageMaps\'] = \''.$this->LANG->getLabel('manageMaps').'\';';
+		$ret .= 'langMenu[\'manageBackends\'] = \''.$this->LANG->getLabel('manageBackends').'\';';
+		$ret .= 'langMenu[\'manageBackgrounds\'] = \''.$this->LANG->getLabel('manageBackgrounds').'\';';
+		$ret .= 'langMenu[\'manageShapes\'] = \''.$this->LANG->getLabel('manageShapes').'\';';
+		$ret .= 'langMenu[\'icon\'] = \''.$this->LANG->getLabel('icon').'\';';
+		$ret .= 'langMenu[\'line\'] = \''.$this->LANG->getLabel('line').'\';';
+		$ret .= 'langMenu[\'special\'] = \''.$this->LANG->getLabel('special').'\';';
+		$ret .= 'langMenu[\'host\'] = \''.$this->LANG->getLabel('host').'\';';
+		$ret .= 'langMenu[\'service\'] = \''.$this->LANG->getLabel('service').'\';';
+		$ret .= 'langMenu[\'hostgroup\'] = \''.$this->LANG->getLabel('hostgroup').'\';';
+		$ret .= 'langMenu[\'servicegroup\'] = \''.$this->LANG->getLabel('servicegroup').'\';';
+		$ret .= 'langMenu[\'map\'] = \''.$this->LANG->getLabel('map').'\';';
+		$ret .= 'langMenu[\'textbox\'] = \''.$this->LANG->getLabel('textbox').'\';';
+		$ret .= 'langMenu[\'shape\'] = \''.$this->LANG->getLabel('shape').'\';';
+		$ret .= 'langMenu[\'manage\'] = \''.$this->LANG->getLabel('manage').'\';';
+		$ret .= 'var lang = Array();';
+		$ret .= 'lang[\'clickMapToSetPoints\'] = \''.$this->LANG->getMessageText('clickMapToSetPoints').'\';';
+		$ret .= 'lang[\'confirmDelete\'] = \''.$this->LANG->getMessageText('confirmDelete').'\';';
+		$ret .= 'lang[\'confirmRestore\'] = \''.$this->LANG->getMessageText('confirmRestore').'\';';
+		$ret .= 'lang[\'wrongValueFormat\'] = \''.$this->LANG->getMessageText('wrongValueFormat').'\';';
+		$ret .= 'lang[\'wrongValueFormatMap\'] = \''.$this->LANG->getMessageText('wrongValueFormatMap').'\';';
+		$ret .= 'lang[\'wrongValueFormatOption\'] = \''.$this->LANG->getMessageText('wrongValueFormatOption').'\';';
+		
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('End method WuiMap::getJsLang(): Array(HTML)');
 		return $ret;	
 	}
 	
+	/**
+	 * Parses the validation regex of the main configuration values to javascript
+	 *
+	 * @return	String Html
+	 * @author Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function getJsValidMainConfig() {
+		return 'var validMainConfig = '.json_encode($this->MAINCFG->getValidConfig()).';';
+	}
+	
+	/**
+	 * Parses the validation regex of the map configuration values to javascript
+	 *
+	 * @return	String Html
+	 * @author Lars Michelsen <lars@vertical-visions.de>
+	 */
+	function getJsValidMapConfig() {
+		return 'var validMapConfig = '.json_encode($this->MAPCFG->getValidConfig()).';';
+	}
+	
 	/**
 	 * Parses the invisible forms and JS arrays needed in WUI
 	 *
@@ -530,7 +674,6 @@ class WuiMap extends GlobalMap {
 	 * @author Lars Michelsen <lars@vertical-visions.de>
      */
 	function parseInvisible() {
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::parseInvisible()');
 		$arr = Array();
 		
 		##################################
@@ -566,7 +709,6 @@ class WuiMap extends GlobalMap {
 			myshape_background.paint();
 			"));
 		
-		if (DEBUG&&DEBUGLEVEL&1) debug('Start method WuiMap::parseInvisible(): Array(HTML)');
 		return $arr;
 	}
 }
