@@ -1395,6 +1395,20 @@ at http://www.walterzorn.com/dragdrop/api_e.htm (english) or
 http://www.walterzorn.de/dragdrop/api.htm (german)	*/
 function my_PickFunc()
 {
+	// Save old coords
+	dd.obj.oldX = dd.obj.x;
+	dd.obj.oldY = dd.obj.y;
+	
+	// Check if this is a box
+	if(dd.obj.name.search('box_') != -1) {
+		// When this object has a relative coordinated label, then move this too
+		var sLabelName = dd.obj.name.replace('box_','rel_label_');
+		var oLabel = document.getElementById(sLabelName);
+		if(oLabel) {
+			ADD_DHTML(sLabelName);
+			dd.obj.addChild(sLabelName);
+		}
+	}
 }
 
 
@@ -1438,14 +1452,25 @@ function my_DropFunc() {
 	var names = "";
 	var coord_x = "";
 	var coord_y = "";
-			
+	
+	// When x or y are negative just return this and make no change
+	if(dd.obj.y < 0 || dd.obj.x < 0) {
+		dd.obj.moveTo(dd.obj.oldX, dd.obj.oldY);
+		return;
+	}
+	
+	// Dragging of relative labels is not allowed, revert it
+	if(dd.obj.name.search('rel_label_') != -1) {
+		dd.obj.moveTo(dd.obj.oldX, dd.obj.oldY);
+		return;
+	}
+	
 	for (cpt = dd.elements.length - 1; cpt >=0  ; cpt--) {
 		names = names + dd.elements[cpt].name.replace("box_","") + ",";
 		myposx = dd.elements[cpt].x;
 		myposy = dd.elements[cpt].y;
 		coord_x = coord_x + myposx + ",";
 		coord_y = coord_y + myposy + ",";
-
 	}
 	
 	// we remove the final comma
